@@ -7,7 +7,6 @@
 
 #include "taskmanagerplugin.h"
 #include "backend.h"
-#include "draghelper.h"
 
 #include "smartlaunchers/smartlauncheritem.h"
 
@@ -15,9 +14,7 @@
 
 void TaskManagerPlugin::registerTypes(const char *uri)
 {
-    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.plasma.private.taskmanager"));
     qmlRegisterType<Backend>(uri, 0, 1, "Backend");
-    qmlRegisterType<DragHelper>(uri, 0, 1, "DragHelper");
 
     qmlRegisterType<SmartLauncher::Item>(uri, 0, 1, "SmartLauncherItem");
 }
