@@ -31,6 +31,7 @@
 #include <KWindowInfo>
 #include <KWindowSystem>
 #include <KX11Extras>
+#include <waylandtasksmodel.h>
 #include <windowtasksmodel.h>
 #include <xwindowtasksmodel.h>
 
@@ -44,7 +45,7 @@ bool areModifiersPressed(const QKeySequence &seq)
     if (seq.isEmpty()) {
         return false;
     }
-    int mod = seq[seq.count() - 1] & Qt::KeyboardModifierMask;
+    int mod = seq[seq.count() - 1].keyboardModifiers();
     auto activeMods = qGuiApp->queryKeyboardModifiers();
     return activeMods & mod;
 }
@@ -187,6 +188,15 @@ SwitcherBackend::SwitcherBackend(QObject *parent)
 
     connect(&m_activities, &KActivities::Controller::currentActivityChanged, this, &SwitcherBackend::onCurrentActivityChanged);
     m_previousActivity = m_activities.currentActivity();
+
+    // migrate values to state location
+    KConfig oldConfig(QStringLiteral("kactivitymanagerd-switcher"));
+    KConfigGroup oldTimes(&oldConfig, QStringLiteral("LastUsed"));
+
+    KConfig stateConfig(QStringLiteral("plasma/activitiesstaterc"), KConfig::SimpleConfig, QStandardPaths::GenericStateLocation);
+    KConfigGroup times = stateConfig.group(QStringLiteral("LastUsed"));
+
+    oldTimes.moveValuesTo(times);
 }
 
 SwitcherBackend::~SwitcherBackend()
@@ -290,7 +300,7 @@ void SwitcherBackend::onCurrentActivityChanged(const QString &id)
     KActivities::Info activity(id);
     Q_EMIT showSwitchNotification(id, activity.name(), activity.icon());
 
-    KConfig config(QStringLiteral("kactivitymanagerd-switcher"));
+    KConfig config(QStringLiteral("plasma/activitiesstaterc"), KConfig::SimpleConfig, QStandardPaths::GenericStateLocation);
     KConfigGroup times(&config, QStringLiteral("LastUsed"));
 
     const auto now = QDateTime::currentDateTime().toSecsSinceEpoch();
@@ -446,6 +456,17 @@ void SwitcherBackend::setDropMode(bool value)
     }
 }
 
+bool SwitcherBackend::dragContainsWindows(QMimeData *mimeData) const
+{
+    if (KWindowSystem::isPlatformX11()) {
+        return TaskManager::XWindowTasksModel::winIdsFromMimeData(mimeData).count();
+    }
+    if (KWindowSystem::isPlatformWayland()) {
+        return TaskManager::WaylandTasksModel::winIdsFromMimeData(mimeData).count();
+    }
+    return false;
+}
+
 void SwitcherBackend::toggleActivityManager()
 {
     auto message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.plasmashell"),
