@@ -8,6 +8,7 @@
 
 #include <KConfigGroup>
 #include <KDesktopFile>
+#include <KLocalizedString>
 
 #include "kcmkeys_debug.h"
 
@@ -147,11 +148,14 @@ QVariant BaseModel::data(const QModelIndex &index, int role) const
         const Action &action = m_components[index.parent().row()].actions[index.row()];
         switch (role) {
         case Qt::DisplayRole: {
-            KDesktopFile desktopFile(action.id);
+            KDesktopFile desktopFile(m_components[index.parent().row()].id);
             KConfigGroup cg = desktopFile.desktopGroup();
             if (cg.readEntry<bool>("X-KDE-GlobalAccel-CommandShortcut", false)) {
                 return cg.readEntry("Exec");
             }
+            if (action.id == "_launch") {
+                return i18nc("@title:group Launch app", "Launch");
+            }
             return action.displayName.isEmpty() ? action.id : action.displayName;
         }
         case ActionRole:
@@ -177,7 +181,7 @@ QVariant BaseModel::data(const QModelIndex &index, int role) const
         KDesktopFile desktopFile(component.id);
         KConfigGroup cg = desktopFile.desktopGroup();
         if (cg.readEntry<bool>("X-KDE-GlobalAccel-CommandShortcut", false)) {
-            return cg.readEntry("Exec");
+            return cg.readEntry("Name");
         }
         return component.displayName;
     }
